@@ -20,7 +20,7 @@ for (t in 1:T) {
     experts[t, , 2] <- qnorm(prob_grid, mean = 5, sd = 2)
 }
 
-# We expect that grids do effect the performance:
+# We expect that grids do affects the performance:
 boa_smooth <- online(
     y = matrix(y),
     tau = prob_grid,
@@ -28,14 +28,7 @@ boa_smooth <- online(
     p_smooth_pr = list(
         lambda = c(10, 1000),
         ndiff = c(1, 2),
-        deg = c(2, 3),
-        knot_distance = c(0.001, 0.1),
-        knot_distance_power = c(0.5, 1, 2)
-    ),
-    b_smooth_pr = list(
-        deg = 1,
-        knot_distance = 0.01,
-        knot_distance_power = 1
+        deg = c(2, 3)
     ),
     trace = FALSE
 )
@@ -47,11 +40,18 @@ expect_true(
     all(!duplicated(apply(boa_smooth$past_performance, 3, mean)))
 )
 
+# Enshure that development does not affect the performance:
+expect_true(
+    all(
+        round(tail(boa_smooth$forecaster_loss)[, , 80], 7) ==
+            c(0.1551044, 0.2390565, 0.3468112, 0.2466774, 0.4535191, 0.2875674)
+    )
+)
+
 boa_smooth <- online(
     y = matrix(y),
     tau = prob_grid,
     experts = experts,
-    b_smooth_pr = list(knot_distance = 0.1),
     p_smooth_pr = list(
         lambda = c(1),
         ndiff = seq(from = 1, to = 2, by = 0.2)
@@ -64,7 +64,7 @@ expect_true(
 )
 
 # Test forget_past_performance
-# We expect that grids do effect the performance:
+# We expect that forget affects the performance:
 without_forget <- online(
     y = matrix(y),
     tau = prob_grid,
@@ -72,8 +72,7 @@ without_forget <- online(
     p_smooth_pr = list(
         knots = c(5, 10, 20),
         lambda = c(1, 10, 100, 1000),
-        ndiff = c(1, 1.5, 2),
-        deg = c(1, 2, 3)
+        ndiff = c(1, 1.5, 2)
     ),
     forget_past_performance = 0,
     trace = FALSE
@@ -89,8 +88,7 @@ with_forget <- online(
     p_smooth_pr = list(
         knots = c(5, 10, 20),
         lambda = c(1, 10, 100, 1000),
-        ndiff = c(1, 1.5, 2),
-        deg = c(1, 2, 3)
+        ndiff = c(1, 1.5, 2)
     ),
     forget_past_performance = 0.01,
     trace = FALSE
